==> imageio-ext-gdalbsb-2.0.0-sources.jar: it/geosolutions/imageio/plugins/bsb/BSBImageReader.java <==
/*
 *    ImageI/O-Ext - OpenSource Java Image translation Library
 *    http://www.geo-solutions.it/
 *    https://github.com/geosolutions-it/imageio-ext
 *    (C) 2007 - 2011, GeoSolutions
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    either version 3 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package it.geosolutions.imageio.plugins.bsb;

import it.geosolutions.imageio.gdalframework.GDALImageReader;

import java.awt.image.RenderedImage;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * {@link BSBImageReader} is a {@link GDALImageReader} able to create
 * {@link RenderedImage} from BSB files.
 * 
 * @author Julien Carlos, INT.
 */
public class BSBImageReader extends GDALImageReader {
    private static final Logger LOGGER = Logger.getLogger("it.geosolutions.imageio.plugins.bsb");

    /**
     * Constructs a <code>BSBImageReader<code> using a {@link BSBImageReaderSpi}.
     * 
     * @param originatingProvider The {@link BSBImageReaderSpi} to use for building this <code>BSBImageReader<code>.
     */
    public BSBImageReader(BSBImageReaderSpi originatingProvider) {
        super(originatingProvider, 0);
        
        if (LOGGER.isLoggable(Level.FINE))
            LOGGER.fine("BSBImageReaderSpi Constructor");
    }

}

==> imageio-ext-gdalbsb-2.1-20251028.084829-2-sources.jar: it/geosolutions/imageio/plugins/bsb/BSBImageReader.java <==
/*
 *    ImageI/O-Ext - OpenSource Java Image translation Library
 *    http://www.geo-solutions.it/
 *    https://github.com/geosolutions-it/imageio-ext
 *    (C) 2007 - 2011, GeoSolutions
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    either version 3 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package it.geosolutions.imageio.plugins.bsb;

import it.geosolutions.imageio.gdalframework.GDALImageReader;
import java.awt.image.RenderedImage;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * {@link BSBImageReader} is a {@link GDALImageReader} able to create {@link RenderedImage} from BSB files.
 *
 * @author Julien Carlos, INT.
 */
public class BSBImageReader extends GDALImageReader {
    private static final Logger LOGGER = Logger.getLogger("it.geosolutions.imageio.plugins.bsb");

    /**
     * Constructs a <code>BSBImageReader<code> using a {@link BSBImageReaderSpi}.
     *
     * @param originatingProvider The {@link BSBImageReaderSpi} to use for building this <code>BSBImageReader<code>.
     */
    public BSBImageReader(BSBImageReaderSpi originatingProvider) {
        super(originatingProvider, 0);

        if (LOGGER.isLoggable(Level.FINE)) LOGGER.fine("BSBImageReaderSpi Constructor");
    }
}
